#coding: UTF-8
#
#  @file FactoryResetSample_20231020.py
#  @brief PMX FactryReset sample code 
#  @author Kondo Kagaku Co.,Ltd.
#  @date 2023/10/20
#

#   
#   FactoryResetSample_20231020.pyはPMXのFactryReset関数を実行するサンプルコードです。
#   FactoryResetSample_20231020.py is a sample code that executes PMX's FactryReset functions.
#

import sys
import os
import time


# PmxLib import
# ライブラリのパスはフォルダの構成によって変わります
# 現在のスクリプトのディレクトリを取得
current_dir = os.path.dirname(__file__)
# 1つ上のフォルダを取得(sanpleのフォルダの同じディレクトリにPmxLibがあるため)
parent_dir = os.path.dirname(current_dir)
# Pmxのライブラリのパスを登録
pmxLibPath = parent_dir + '\PmxLib'
sys.path.append(pmxLibPath)

from PmxPySerialClass  import PmxPySerialClass  # pySerialでPMXを通信するクラスをつかるようにする
from PmxLib import PmxLib as PMX  # PMXの固有値が定義してある「PmxLib」をPMXという名前で使えるようにする


# クラスをインスタンス化
pmx = PmxPySerialClass()

# 通信の設定項目
#comName = "/dev/ttyUSB0"
comName = "COM5"
pmxBaudrate = 3000000
pmxTimeout = 1.0

ServoID = 0

"""Serial open"""
def serialPortOpen():
    ### COM open
    openFlag = pmx.open(comName, baudrate=pmxBaudrate, timeout=pmxTimeout)
    if openFlag == False:
        print("Serial not open. Exit program")
        exit()
    else:
        print("Serial Connect success")




""" Main処理 """
def main():


    # 通信ログを表示させる(表示：True,非表示：False)
    pmx.logOutput = False
    # COMを開く
    serialPortOpen()

    
    # 工場出荷状態に戻す
    print('ROMの状態を工場出荷状態に戻します')
    # flag = pmx.FactoryReset(ServoID, serialNum)  # id, シリアル番号
    flag = pmx.FactoryReset(ServoID)  # id # シリアル番号がわからない場合
    if flag != 0x00:
        print("FactoryResetコマンドを送ったらエラーが返ってきました(", hex(flag), ")")
    else:
        print("FactoryResetコマンドが正常に動作しました(", hex(flag), ")")
    
    # サーボのFactoryResetコマンドの処理が完了するまで待つ
    time.sleep(0.5)
    
    
    pmx.close()


""" main """
if __name__ == "__main__":
    main()
