#coding: UTF-8
#
#  @file LOAD_Sample20231020.py
#  @brief PMX Load sample code 
#  @author Kondo Kagaku Co.,Ltd.
#  @date 2023/10/20
#

#   
#   LOAD_Sample20231020.pyはPMXのLOAD関数を実行するサンプルコードです。
#   LOAD_Sample20231020py is a sample code that executes PMX's LOAD functions.
#

import sys
import os
import time

# PmxLib import
# ライブラリのパスはフォルダの構成によって変わります
# 現在のスクリプトのディレクトリを取得
current_dir = os.path.dirname(__file__)
# 1つ上のフォルダを取得(sanpleのフォルダの同じディレクトリにPmxLibがあるため)
parent_dir = os.path.dirname(current_dir)
# Pmxのライブラリのパスを登録
pmxLibPath = parent_dir + '\PmxLib'
sys.path.append(pmxLibPath)

from PmxPySerialClass  import PmxPySerialClass  # pySerialでPMXを通信するクラスをつかるようにする
from PmxLib import PmxLib as PMX  # PMXの固有値が定義してある「PmxLib」をPMXという名前で使えるようにする

# クラスをインスタンス化
pmx = PmxPySerialClass()


# 通信の設定項目
#comName = "/dev/ttyUSB0"
comName = "COM5"
pmxBaudrate = 3000000
pmxTimeout = 1.0

ServoID = 0

"""Serial open"""
def serialPortOpen():
    ###COM open
    openFlag = pmx.open(comName, baudrate=pmxBaudrate, timeout=pmxTimeout)
    if openFlag == False:
        print("Serial not open. Exit program")
        exit()
    else:
        print("Serial Connect success")




""" Main処理 """
def main():


    # 通信ログを表示させる(表示：True,非表示：False)
    pmx.logOutput = False
    # COMを開く
    serialPortOpen()


    # LOAD関数を使ってROMに保存されたデータをRAMに展開する
    print('ROMに保存されたデータをRAMに展開します')
    flag = pmx.LOAD(ServoID)  # id 
    if flag != 0x00:
        print("Loadコマンドを送ったらエラーが返ってきました(", hex(flag), ")")
    else:
        print("Loadコマンドが正常に動作しました(", hex(flag), ")")
    
    
    
    
    # サーボのLOADコマンドの処理が完了するまで待つ
    time.sleep(0.5)
    
    
    pmx.close() #COMを閉じます


""" main """
if __name__ == "__main__":
    main()
