#coding: UTF-8

#
#  @file MemWRITE_MotorControl_Sample20240215.py
#  @brief MemWRITE MotorControl sample code 
#  @author Kondo Kagaku Co.,Ltd.
#  @date 2024/2/15
#

#   
#   MemWRITE_MotorControl_Sample20240215.pyはPMXのMemWRITE関数を使用してモータを制御するサンプルコードです。
#   MemWRITE_MotorControl_Sample20240215.py is a sample code that controls a motor using the MemWRITE function of PMX.
#


import sys
import os
import time


# PmxLib import
# ライブラリのパスはフォルダの構成によって変わります
# 現在のスクリプトのディレクトリを取得
current_dir = os.path.dirname(__file__)
# 1つ上のフォルダを取得
parent_dir = os.path.dirname(current_dir)
# Pmxのライブラリのパスを登録
pmxLibPath = parent_dir + '\PmxLib'
sys.path.append(pmxLibPath)

from PmxPySerialClass  import PmxPySerialClass
from PmxLib import PmxLib as PMX


# クラスをインスタンス化
pmx = PmxPySerialClass()

# 通信の設定項目
# comName = "/dev/ttyUSB0"
comName = "COM5"
pmxBaudrate = 3000000
pmxTimeout = 1.0

ServoID = 0

"""Serial open"""
def serialPortOpen():
    ###COM open
    openFlag = pmx.open(comName, baudrate=pmxBaudrate, timeout=pmxTimeout)
    if openFlag == False:
        print("Serial not open. Exit program")
        exit()
    else:
        print("Serial Connect success")
      



""" Main処理 """
def main():


    # 通信ログを表示させる(表示：True,非表示：False)
    pmx.logOutput = False
    # COMを開く
    serialPortOpen()

    """制御モードが1つの場合"""
    # 制御モードの設定：位置制御
    print('位置制御モードを指定')
    controlMode = PMX.ControlMode.Position
    status = pmx.setControlMode(ServoID, controlMode, writeOpt=1)
    print("setControlMode", hex(status))
    
    # トルクスイッチ：TorqueON
    flag = pmx.setTorqueSwitch(ServoID, PMX.TorqueSwitchType.TorqueOn, writeOpt=1)
    print("MotorTorqueOn", hex(flag))

    # MemWRITEコマンドで目標指令値1（700番地）にデータを書き込んで動作指示
    print('位置制御の指令値として90°を指定')
    flag = pmx.MemWRITEToInt16(ServoID, PMX.RamAddrList.GoalCommandValue1, 9000, writeOpt=0x01)  # id , Addr ,data, writeOpt
    print(hex(flag))

    #現在位置は位置制御モードとその他の制御モードで値が異なるため制御モードを引数で渡します
    print("現在位置", pmx.getPosition(ServoID, contolMode=controlMode))
    print("現在速度", pmx.getSpeed(ServoID))
    print("現在電流値", pmx.getCurrent(ServoID))

    time.sleep(1)

    print('位置制御の指令値として0°を指定')
    flag = pmx.MemWRITEToInt16(ServoID, PMX.RamAddrList.GoalCommandValue1, 0, writeOpt=0x01)  # id , Addr ,data, writeOpt
    print(hex(flag))

    time.sleep(1)
    


    """制御モードが2つの場合"""
    #誤動作を防ぐため、制御モードを切り替えるまえにFreeモードに切り替える
    print('トルクスイッチに8(Hold)を書き込みます')
    flag = pmx.setTorqueSwitch(ServoID, PMX.TorqueSwitchType.Brake, writeOpt=1)
    print(hex(flag))

    # 制御モードを変更:位置制御+電流制御
    print('位置制御+電流制御モードを指定')
    controlMode = PMX.ControlMode.PositionCurrent
    status = pmx.setControlMode(ServoID, controlMode, writeOpt=1)
    print("setControlMode", hex(status))

    # トルクスイッチ：TorqueON
    flag = pmx.setTorqueSwitch(ServoID, PMX.TorqueSwitchType.TorqueOn, writeOpt=1)
    print("MotorTorqueOn", hex(flag))

    # MemWRITEコマンドで目標指令値2（702番地）にデータを書き込んで動作指示
    print('電流制御の指令値として200mAを指定')
    flag = pmx.MemWRITEToInt16(ServoID, PMX.RamAddrList.GoalCommandValue2, 200, writeOpt=0x01)  # id , Addr ,data, writeOpt
    print(hex(flag))

    # MemWRITEコマンドで目標指令値1（700番地）にデータを書き込んで動作指示
    print('位置制御の指令値として90°を指定')
    flag = pmx.MemWRITEToInt16(ServoID, PMX.RamAddrList.GoalCommandValue1, 9000, writeOpt=0x01)  # id , Addr ,data, writeOpt
    print(hex(flag))
    
    time.sleep(1.5)

    print('位置制御の指令値として0°を指定')
    flag = pmx.MemWRITEToInt16(ServoID, PMX.RamAddrList.GoalCommandValue1, 0, writeOpt=0x01)  # id , Addr ,data, writeOpt
    print(hex(flag))

    time.sleep(1.5)



    """移動時間と組み合わせた位置制御の場合"""
    #誤動作を防ぐため、制御モードを切り替えるまえにHoldモードに切り替える
    print('トルクスイッチに8(Hold)を書き込みます')
    flag = pmx.setTorqueSwitch(ServoID, PMX.TorqueSwitchType.Brake, writeOpt=1)
    print(hex(flag))

    # 制御モードを変更:位置制御+移動時間
    print('位置制御+移動時間モードを指定')
    controlMode = PMX.ControlMode.PositionTime
    status = pmx.setControlMode(ServoID, controlMode, writeOpt=1)
    print("setControlMode", hex(status))

    # 補間モードを指定
    print('補間モードを均等補間に指定')
    status = pmx.setTrajectory(ServoID, PMX.TrajectoryType.Even, writeOpt=1)
    print("setTrajectory", hex(status))
    
    # トルクスイッチ：TorqueON
    flag = pmx.setTorqueSwitch(ServoID, PMX.TorqueSwitchType.TorqueOn, writeOpt=1)
    print("MotorTorqueOn", hex(flag))

    # MemWRITEコマンドで目標指令値2（702番地）にデータを書き込んで動作指示
    print('移動時間の指令値として1000msを指定')
    flag = pmx.MemWRITEToUint16(ServoID, PMX.RamAddrList.GoalCommandValue2, 1000, writeOpt=0x01)  # id , Addr ,data, writeOpt
    print(hex(flag))

    # MemWRITEコマンドで目標指令値1（700番地）にデータを書き込んで動作指示
    print('位置制御の指令値として90°を指定')
    flag = pmx.MemWRITEToInt16(ServoID, PMX.RamAddrList.GoalCommandValue1, 9000, writeOpt=0x01)  # id , Addr ,data, writeOpt
    print(hex(flag))
    
    time.sleep(1.5)

    print('位置制御の指令値として0°を指定')
    flag = pmx.MemWRITEToInt16(ServoID, PMX.RamAddrList.GoalCommandValue1, 0, writeOpt=0x01)  # id , Addr ,data, writeOpt
    print(hex(flag))

    time.sleep(1.5)




    print('トルクスイッチに2(Free)を書き込みます')
    flag = pmx.setTorqueSwitch(ServoID, PMX.TorqueSwitchType.Free, writeOpt=1)
    print(hex(flag))


    pmx.close()  # COMを閉じます


""" main """
if __name__ == "__main__":
    main()
