#coding: UTF-8

#
#  @file MemWRITE_Sample20231023.py
#  @brief MemWRITE sample code 
#  @author Kondo Kagaku Co.,Ltd.
#  @date 2023/10/23
#

#   
#   MemWRITE_Sample20231023.pyはPMXのMemWRITE関数に関する関数を実行するサンプルコードです。
#   MemWRITE_Sample20231023.py is a sample code that executes functions related to the MemWRITE function of PMX.
#


import sys
import os
import time


# PmxLib import
# ライブラリのパスはフォルダの構成によって変わります
# 現在のスクリプトのディレクトリを取得
current_dir = os.path.dirname(__file__)
# 1つ上のフォルダを取得
parent_dir = os.path.dirname(current_dir)
# Pmxのライブラリのパスを登録
pmxLibPath = parent_dir + '\PmxLib'
sys.path.append(pmxLibPath)

from PmxPySerialClass  import PmxPySerialClass
from PmxLib import PmxLib as PMX


# クラスをインスタンス化
pmx = PmxPySerialClass()

# 通信の設定項目
# comName = "/dev/ttyUSB0"
comName = "COM5"
pmxBaudrate = 3000000
pmxTimeout = 1.0

ServoID = 0

"""Serial open"""
def serialPortOpen():
    ###COM open
    openFlag = pmx.open(comName, baudrate=pmxBaudrate, timeout=pmxTimeout)
    if openFlag == False:
        print("Serial not open. Exit program")
        exit()
    else:
        print("Serial Connect success")
        



""" Main処理 """
def main():


    # 通信ログを表示させる(表示：True,非表示：False)
    pmx.logOutput = False
    # COMを開く
    serialPortOpen()
    

    # MemWRITE関数を直接使って入力最小電圧値に9500を書き込む
    newMinVoltageLimit = 9500
    writeDataArray = newMinVoltageLimit.to_bytes(length=2, byteorder="little", signed=False)
    print('76番地(入力電圧最小値設定)に[9500](9.5V)を書き込みます')
    flag = pmx.MemWRITE(ServoID, PMX.RamAddrList.MinVoltageLimit, writeDataArray)  # id , Addr ,data
    print(hex(flag))

    # 正しく書き込めたかを確認するため、同じ番地からデータを読み出す
    print('76番地(入力電圧最小値設定)から2byte読み出します(返り値はbytes型)')
    flag, dataArray = pmx.MemREAD(ServoID, PMX.RamAddrList.MinVoltageLimit, 2)  # id , Addr ,dataSize
    data = int.from_bytes(dataArray, byteorder="little", signed=True)
    print("入力電圧最小値設定", data)


    
    # 下記の関数を使用することで、データを分割することなくMemWRITEを実行できる    
    # MemWRITE関数を使ってCW方向のリミット角度値(int16(符号あり2byte))に25000を書き込む
    # MemWRITE自体TorqueOn状態の場合は書き込めない仕様だが、オプションを0x01にすることによりTorqueOn状態でも書き込めるようになる

    # 符号あり2byte型の場合
    print('CW方向最大角値に25000を書き込みます')
    flag = pmx.MemWRITEToInt16(ServoID, PMX.RamAddrList.CwPositionLimit, 25000, writeOpt=0x01)  # id , Addr ,data, writeOpt
    print(hex(flag))
    
    # 同じアドレスのデータをMemREAD関数で読み出し、書き込んだデータが書き込めているか確認をする
    print('CW方向最大角値を読み出します')
    flag, data = pmx.MemREADToInt16(ServoID, PMX.RamAddrList.CwPositionLimit)  # id , Addr ,dataSize
    print(hex(flag), data)


    # 符号なし2byte型の場合
    print('入力電圧最大値設定に13000を書き込みます')
    flag = pmx.MemWRITEToUint16(ServoID, PMX.RamAddrList.MaxVoltageLimit, 13000, writeOpt=0x01)  # id , Addr ,data, writeOpt
    print(hex(flag))
    
    # 同じアドレスのデータをMemREAD関数で読み出し、書き込んだデータが書き込めているか確認をする
    print('入力電圧最小値設定を読み出します')
    flag, data = pmx.MemREADToUint16(ServoID, PMX.RamAddrList.MaxVoltageLimit)  # id , Addr ,dataSize
    print(hex(flag), data)


    # 符号なし4byte型の場合
    print('位置制御のPゲインに2000を書き込みます')
    flag = pmx.MemWRITEToUint32(ServoID, PMX.RamAddrList.PositionKp, 2000, writeOpt=0x01)  # id , Addr ,data, writeOpt
    print(hex(flag))
    
    # 同じアドレスのデータをMemREAD関数で読み出し、書き込んだデータが書き込めているか確認をする
    print('位置制御のPゲインを読み出します')
    flag, data = pmx.MemREADToUint32(ServoID, PMX.RamAddrList.PositionKp)  # id , Addr ,dataSize
    print(hex(flag), data)
    

    # 符号なし1byte型の場合
    print('トルクスイッチに2(Free)を書き込みます')
    # TorqueSwitch Data: 0x01=TorqueON, 0x02=Free, 0x04=Brake, 0x08=Hold
    flag = pmx.MemWRITEToByte(ServoID, PMX.RamAddrList.TorqueSwitch, 2, writeOpt=0x01)
    print(hex(flag))

    # 同じアドレスのデータをMemREAD関数で読み出し、書き込んだデータが書き込めているか確認をする
    print('トルクスイッチを読み出します')
    flag, data = pmx.MemREADToByte(ServoID, PMX.RamAddrList.TorqueSwitch)  # id , Addr ,dataSize
    print(hex(flag), data)


    # ライブラリには専用の関数を用意している場合があります。
    # 下記は入力電圧最小値設定に書き込むための関数です。これにより、アドレスを指定する必要がなくなり、プログラムもすっきりします。
    # さらに関連する設定値と％の二つの項目を一行で書き込むことが可能です。

    # この関数内でMemWRITEコマンドを実行しています
    print('入力電圧最小値（入力電圧最小値と入力電圧最小時の出力％値）の設定をします')
    flag = pmx.setMinVoltageLimit(ServoID, 8000, 50)  # id , minVol , limPower
    print(hex(flag))  

    # 入力電圧最小値の設定されているか確認
    print('入力電圧最小値（入力電圧最小値と入力電圧最小時の出力％値）を読み出します')
    flag, voldata = pmx.getMinVoltageLimit(ServoID)
    flag, volLimdata = pmx.getMinVoltageLimitPower(ServoID)  # id
    print(hex(flag), voldata, volLimdata)


    # MemWRITEで書き込んだデータを保存する場合は以下のSAVEコマンドを実行してからサーボの電源を切ってください
    
    # # SAVE関数を使ってRAMのデータをROMに保存する
    # print('RAMのデータをROMに保存します')
    # flag = pmx.SAVE(ServoID)  # id 
    # print(hex(flag))
    
    # サーボのSAVEコマンドの処理が完了するまで待つ
    # time.sleep(0.5)

    pmx.close()  # COMを閉じます


""" main """
if __name__ == "__main__":
    main()
