#coding: UTF-8

#
#  @file MotorWRITE_Double_Sample20231023.py
#  @brief MotorREAD MotorWRITE(Double) sample code 
#  @author Kondo Kagaku Co.,Ltd.
#  @date 2023/10/23
#

#   
#   MotorWRITE_Double_Sample20231023.pyはPMXのMotorREAD関数、MotorWRITE(Double)関数に関する関数を実行するサンプルコードです。
#   MotorWRITE_Double_Sample20231023.py is a sample code that executes functions related to the MotorREAD and MotorWRITE functions of PMX.
#

import sys
import os
import time

# PmxLib import
# ライブラリのパスはフォルダの構成によって変わります
# 現在のスクリプトのディレクトリを取得
current_dir = os.path.dirname(__file__)
# 1つ上のフォルダを取得
parent_dir = os.path.dirname(current_dir)
# Pmxのライブラリのパスを登録
pmxLibPath = parent_dir + '\PmxLib'
sys.path.append(pmxLibPath)


from PmxPySerialClass  import PmxPySerialClass
from PmxLib import PmxLib as PMX


# クラスをインスタンス化
pmx = PmxPySerialClass()

# 通信の設定項目
# comName = "/dev/ttyUSB0"
comName = "COM5"
pmxBaudrate = 3000000
pmxTimeout = 1.0

ServoID = 0


"""Serial open"""
def serialPortOpen():
    ###  COM open
    openFlag = pmx.open(comName, baudrate=pmxBaudrate, timeout=pmxTimeout)
    if openFlag == False:
        print("Serial not open. Exit program")
        exit()
    else:
        print("Serial Connect success")
        



""" Main処理 """
def main():


    # 通信ログを表示させる
    pmx.logOutput = False
    # COMを開く
    serialPortOpen()

    # 制御モードの設定します
    # writeOpt=0x01のときはトルクONでも強制的に書き込めます(デフォルト値は0x00)
    # 以下の各ビットを1にすると制御モードとして指定できます
    # Bit7:0 Bit6:0 Bit5:移動時間 Bit4:PWM Bit3:トルク Bit2:電流 Bit1:速度 Bit0:位置
    controlMode = PMX.ControlMode.PositionCurrent  # 位置/電流モード値 
    status = pmx.setControlMode(ServoID, controlMode, writeOpt=0x01)
    print("setControlMode", hex(status))


    # 応答データ指定します
    # writeOpt=0x01のときはトルクONでも強制的に書き込めます(デフォルト値は0x00)
    # 以下の各ビットを1にすると応答データとして指定できます
    # Bit7:入力電圧 Bit6:CPU温度 Bit5:モータ温度 Bit4:PWM出力 Bit3:推定トルク Bit2:電流 Bit1:速度 Bit0:位置
    # receiveMode = PMX.ReceiveDataOption.Position # 位置情報を返す
    # receiveMode = PMX.ReceiveDataOption.Position + PMX.ReceiveDataOption.Current  # 位置と電流を返す
    receiveMode = 0x05  # 数値でも指定できます。0x05は位置と電流を指定
    # receiveMode = PMX.ReceiveDataOption.Full  #　すべて返す
    status = pmx.setMotorReceive(ServoID, receiveMode, writeOpt=0x01)
    print("setMotorReturn", hex(status))


    # サーボのトルクをオンにします
    status, torqueswitch, reData = pmx.setMotorTorqueOn(ServoID, receiveMode)
    print("setMotorTorqueOn", hex(status))
    

    # MotorWRITE関数で動作指令
    pos = -32000  # 位置/電流時の第1引数は位置
    cur = 250  # 位置/電流時の第2引数は電流
    status, torqueswitch, reData = pmx.MotorWRITE(ServoID, 0, controlMode, receiveMode, [pos, cur])
    print("MotorWRITE", hex(status), torqueswitch, reData)

    # 目標地点に到達するまで待ちます
    time.sleep(2)

    
    # MotorWRITEDouble（組合せ2個）で動作指令
    pos = -18000
    cur = 500
    status, torqueswitch, reData = pmx.MotorWRITEDouble(ServoID, controlMode, receiveMode, pos, cur)
    print("MotorWRITE(Double)", hex(status), torqueswitch, reData)

    # 目標地点に到達するまで待ちます
    time.sleep(1)

    
    # setPositon関数を使用した場合
    pos = 0
    cur = 500
    status, torqueswitch, reData = pmx.setPosition(ServoID, receiveMode, pos, current=cur)
    print("SetPositon", hex(status), torqueswitch, reData)
    
    if status == 0:  # エラーではなかった場合は現在位置を表示する
        print("Position>>", reData[0])  # 位置が入るのは0番目

    # 目標地点に到達するまで待ちます
    time.sleep(1)


    # MotorREADで現在の状態を確認
    status, tq, data = pmx.MotorREAD(ServoID, receiveMode, controlMode=controlMode)
    print("MotorREAD", hex(status), data)

    
    # トルクスイッチ：Free    
    status, torqueswitch, reData = pmx.setMotorFree(ServoID, receiveMode)
    print("setMotorFree", hex(status))
    
    pmx.close()  # COMを閉じます


""" main """
if __name__ == "__main__":
    main()
