#coding: UTF-8

#
#  @file MotorWRITE_PosTimeMove_Sample20231023.py
#  @brief PMX Positon/Time Move Sample
#  @author Kondo Kagaku Co.,Ltd.
#  @date 2023/10/23
#

#   
#   MotorWRITE_PosTimeMove_Sample20231023.pyは位置/時間制御動作のサンプルプログラムです。
#   MotorWRITE_PosTimeMove_Sample20231023.py is position/time control sample program
#  
#   補間モードを変えることで加減速具合が変わります 
#   Trajectory Mode changes the acceleration/deceleration rate.
#

import sys
import os
import time

# PmxLib import
# ライブラリのパスはフォルダの構成によって変わります
# 現在のスクリプトのディレクトリを取得
current_dir = os.path.dirname(__file__)
# 1つ上のフォルダを取得
parent_dir = os.path.dirname(current_dir)
# Pmxのライブラリのパスを登録
pmxLibPath = parent_dir + '\PmxLib'
sys.path.append(pmxLibPath)


# pmxをインスタンス化できるようにする
from PmxPySerialClass  import PmxPySerialClass
# PMXの固有値を取得できるようにする
from PmxLib import PmxLib as PMX



# instantiate PmxPySerialClass
pmx = PmxPySerialClass()

# 通信の設定項目
# Communication setting

#comName = "/dev/ttyUSB0"
comName = "COM5"
pmxBaudrate = 3000000
pmxTimeout = 1.0


"""Serial open"""
def serialPortOpen():
    ###COM open
    openFlag = pmx.open(comName, baudrate=pmxBaudrate, timeout=pmxTimeout)
    if openFlag == False:
        print("Serial not open. Exit program")
        exit()
    else:
        print("Serial Connect success")
        

ServoID = 0


""" Main Func """
def main():


    # 通信ログを表示させる(表示：True,非表示：False)
    # Displaying communication log 
    pmx.logOutput = False

    # Serial port Open
    serialPortOpen()

    # 制御モードの設定
    controlMode = PMX.ControlMode.PositionTime  # 位置/時間モード 
    status = pmx.setControlMode(ServoID, controlMode)
    print("setControlMode", hex(status))

    # 応答モードの設定
    receiveMode = PMX.ReceiveDataOption.Position + PMX.ReceiveDataOption.Speed  # 位置と速度を返す
    status = pmx.setMotorReceive(ServoID, receiveMode)
    print("setMotorReturn", hex(status))

    # トルクスイッチ：TorqueON
    status, torqueswitch, reData = pmx.setMotorTorqueOn(ServoID, receiveMode)
    print("MotorTorqueOn", hex(status))
    
    for i in range(3):

        # 補間タイプを均等補間に設定します。トルクON状態なのでwriteOptは0x01にします
        status = pmx.setTrajectory(ServoID, PMX.TrajectoryType.Even, writeOpt=0x01)
        
        # MotorWRITEDouble（組合せ2個）で動作指令(-9000まで1秒で動く)
        pos = -9000  # 位置/時間の第1引数は位置
        setTime = 1000  # 位置/時間の第2引数は時間
        status, torqueswitch, reData = pmx.MotorWRITEDouble(ServoID, controlMode, receiveMode, pos, setTime)
        print("MotorWRITE(Double)", hex(status), torqueswitch, reData)
        if status == 0:  # データが来ている時
            print("Position>>", reData[0])  # 位置が入るのは0番目


        # 目標地点に到達するまで待ちます
        time.sleep(2)
        
        
        # 補間タイプを5次多項式補間に設定します。トルクON状態なのでwriteOptは0x01にします
        status = pmx.setTrajectory(ServoID, PMX.TrajectoryType.FifthPoly, writeOpt=0x01)

        # setPositon関数を使用した場合(9000まで3秒で動く)
        status, torqueswitch, reData = pmx.setPosition(ServoID, receiveMode, 9000, time=3000)
        print("SetPositon", hex(status), torqueswitch, reData)
        if status == 0:  # データが来ている時
            print("Speed>>", reData[1])  # 速度が入るのは1番目

        # 目標地点に到達するまで待ちます
        time.sleep(4)

    
    # 最後は原点まで移動します(0まで保管せず(0秒)で動く)
    status, torqueswitch, reData = pmx.setPosition(ServoID, receiveMode, 0, time=0)
    # 目標地点に到達するまで待ちます
    time.sleep(1)

    # トルクスイッチ：Free
    status, torqueswitch, reData = pmx.setMotorFree(ServoID, receiveMode)
    print("MotorFree", hex(status))
        

    
    pmx.close()


""" main """
if __name__ == "__main__":
    main()
