# coding: UTF-8

#
#  @file MotorWRITE_Speed_Sample20231024.py
#  @brief Speed control sample code 
#  @author Kondo Kagaku Co.,Ltd.
#  @date 2023/10/24
#

#   
#   MotorWRITE_Speed_Sample20231024.pyは速度制御を実行するサンプルコードです。
#   MotorWRITE_Speed_Sample20231024.py is a sample code to perform speed control
#
#   100deg/sで3秒間回ります
#   Rotates for 3 sec at 100deg/s
#

import sys
import os
import time

# PmxLib import
# ライブラリのパスはフォルダの構成によって変わります
# 現在のスクリプトのディレクトリを取得
current_dir = os.path.dirname(__file__)
# 1つ上のフォルダを取得
parent_dir = os.path.dirname(current_dir)
# Pmxのライブラリのパスを登録
pmxLibPath = parent_dir + '\PmxLib'
sys.path.append(pmxLibPath)

from PmxPySerialClass  import PmxPySerialClass
from PmxLib import PmxLib as PMX


# クラスをインスタンス化
pmx = PmxPySerialClass()

# 通信の設定項目
# comName = "/dev/ttyUSB0"
comName = "COM5"
pmxBaudrate = 3000000
pmxTimeout = 1.0

ServoID = 0


"""Serial open"""
def serialPortOpen():
    ### COM open
    openFlag = pmx.open(comName, baudrate=pmxBaudrate, timeout=pmxTimeout)
    if openFlag == False:
        print("Serial not open. Exit program")
        exit()
    else:
        print("Serial Connect success")
        



""" Main処理 """
def main():


    # 通信ログを表示させない
    pmx.logOutput = False
    # COMを開く
    serialPortOpen()

    # 制御モードの設定します
    # writeOpt=0x01のときはトルクONでも強制的に書き込めます(デフォルト値は0x00)
    # 以下の各ビットを1にすると制御モードとして指定できます
    # Bit7:0 Bit6:0 Bit5:移動時間 Bit4:PWM Bit3:トルク Bit2:電流 Bit1:速度 Bit0:位置
    controlMode = PMX.ControlMode.Speed  # 速度制御モード値 
    status = pmx.setControlMode(ServoID, controlMode, writeOpt=0x01)
    print("setControlMode", hex(status))


    # 応答データ指定します
    # writeOpt=0x01のときはトルクONでも強制的に書き込めます(デフォルト値は0x00)
    # 以下の各ビットを1にすると応答データとして指定できます
    # Bit7:入力電圧 Bit6:CPU温度 Bit5:モータ温度 Bit4:PWM出力 Bit3:推定トルク Bit2:電流 Bit1:速度 Bit0:位置
    # receiveMode = PMX.ReceiveDataOption.Position # 位置情報を返す
    receiveMode = PMX.ReceiveDataOption.Full  # すべて返す
    # receiveMode = 0xFF # 数値でも指定できます。
    status = pmx.setMotorReceive(ServoID, receiveMode, writeOpt=0x01)
    print("setMotorReceive", hex(status))


    # サーボのトルクをオンにします
    status, torqueswitch, reData = pmx.setMotorTorqueOn(ServoID, receiveMode)
    print("setMotorTorqueOn", hex(status))
    

    # MotorWRITESingle（組合せ1個）で動作指令
    val = 1000  # 速度制御の第1引数は速度(x10 deg/s)
    status, torqueswitch, reData = pmx.MotorWRITESingle(ServoID, controlMode, receiveMode, val)
    print("MotorWRITE(Single)", hex(status), torqueswitch, reData)

    # 3秒間回転
    time.sleep(3)
    
    
    val = 0     # 動作を停止します。
    status, torqueswitch, reData = pmx.MotorWRITESingle(ServoID, controlMode, receiveMode, val)
    print("MotorWRITE(Single)", hex(status), torqueswitch, reData)


    
    # トルクスイッチ：Free    
    status, torqueswitch, reData = pmx.setMotorFree(ServoID, receiveMode)
    print("setMotorFree", hex(status))
    
    pmx.close()  # COMを閉じます


""" main """
if __name__ == "__main__":
    main()
