#coding: UTF-8
#
#  @file ReBoot_Sample20231020.py
#  @brief PMX Reboot sample code 
#  @author Kondo Kagaku Co.,Ltd.
#  @date 2023/10/20
#

#   
#   ReBoot_Sample20231020pyはPMXのReboot関数を実行するサンプルコードです。
#   ReBoot_Sample20231020.py is a sample code that executes PMX's Reboot functions.
#

import sys
import os
import time

# PmxLib import
# ライブラリのパスはフォルダの構成によって変わります
# 現在のスクリプトのディレクトリを取得
current_dir = os.path.dirname(__file__)
# 1つ上のフォルダを取得
parent_dir = os.path.dirname(current_dir)
# Pmxのライブラリのパスを登録
pmxLibPath = parent_dir + '\PmxLib'
sys.path.append(pmxLibPath)


# pmxをインスタンス化できるようにする
from PmxPySerialClass  import PmxPySerialClass
# PMXの固有値を取得できるようにする
from PmxLib import PmxLib as PMX


# クラスをインスタンス化
pmx = PmxPySerialClass()

# 通信の設定項目
#comName = "/dev/ttyUSB0"
comName = "COM5"
pmxBaudrate = 3000000
pmxTimeout = 1.0

ServoID = 0

"""Serial open"""
def serialPortOpen():
    ###COM open
    openFlag = pmx.open(comName, baudrate=pmxBaudrate, timeout=pmxTimeout)
    if openFlag == False:
        print("Serial not open. Exit program")
        exit()
    else:
        print("Serial Connect success")




""" Main処理 """
def main():


    # 通信ログを表示させる(表示：True,非表示：False)
    pmx.logOutput = False
    # COMを開く
    serialPortOpen()
    
    
    # サーボを再起動する
    print('サーボを再起動します')
    flag = pmx.ReBoot(ServoID, resetTime=500)  # id, 再起動時間(ms)
    if flag != 0x00:
        print("ReBootコマンドを送ったらエラーが返ってきました(", hex(flag), ")")
    else:
        print("ReBootコマンドが正常に動作しました(", hex(flag), ")")
    
    
    
    # サーボのReBootコマンドの処理が完了するまで待つ
    time.sleep(0.5)
    
    
    pmx.close()  # COMを閉じます。


""" main """
if __name__ == "__main__":
    main()
