#coding: UTF-8

#
#  @file SystemREAD_WRITE_Sample20231023.py
#  @brief SystemREAD SystemWRITE sample code 
#  @author Kondo Kagaku Co.,Ltd.
#  @date 2023/10/23
#

#   
#   SystemREAD_WRITE_Sample20231023.pyはPMXのSystemREAD関数、SystemWRITE関数に関する関数を実行するサンプルコードです。
#   SystemREAD_WRITE_Sample20231023.py is a sample code that executes functions related to the SystemREAD and SystemWRITE functions of PMX.
#

import sys
import os
import time

# PmxLib import
# ライブラリのパスはフォルダの構成によって変わります
# 現在のスクリプトのディレクトリを取得
current_dir = os.path.dirname(__file__)
# 1つ上のフォルダを取得
parent_dir = os.path.dirname(current_dir)
# Pmxのライブラリのパスを登録
pmxLibPath = parent_dir + '\PmxLib'
sys.path.append(pmxLibPath)



# pmxをインスタンス化できるようにする
from PmxPySerialClass  import PmxPySerialClass
# PMXの固有値を取得できるようにする
from PmxLib import PmxLib as PMX

import time

# クラスをインスタンス化
pmx = PmxPySerialClass()

# 通信の設定項目
# comName = "/dev/ttyUSB0"
comName = "COM5"
pmxBaudrate = 3000000
pmxTimeout = 1.0

ServoID = 0


"""Serial open"""
def serialPortOpen():
    ###COM open
    openFlag = pmx.open(comName, baudrate=pmxBaudrate, timeout=pmxTimeout)
    if openFlag == False:
        print("Serial not open. Exit program")
        exit()
    else:
        print("Serial Connect success")
        
    



""" Main処理 """
def main():


    # 通信ログを表示させる(表示：True,非表示：False)
    pmx.logOutput = False
    # COMを開く
    serialPortOpen()
    

    print('SystemReadでデータを取得します')
    flag, sysDatas = pmx.SystemREAD(ServoID)
    print(hex(flag))
    print("シリアル番号", sysDatas[0])
    print("製品番号", sysDatas[1])
    print("F/Wバージョン", sysDatas[2])
    print("応答時間", sysDatas[3])
    
    print('getSerialNumberでも取得できます')
    flag, serialNum = pmx.getSerialNumber(ServoID)
    
    if serialNum is None:
        print("シリアル番号が取得できないので終了します>>", hex(flag))
        sys.exit()
    
    
    print("SystemWRITEを使用してID等を書き変えます")
    nowID = ServoID  # 書き変える前のID 
    newID = 10  # 新しいID
    newBaudrateVal = PMX.EditBaudrate._3000000  # SystemWriteではbaudrate値を直接書くのでEditBaudrateを使用する
    newBaudrate = 3000000
    newParity = PMX.EditParity.ParityNone # 新しいパリティ
    newRespTime = 50 # 新しい応答時間
    
    flag = pmx.SystemWRITE(nowID, serialNum=serialNum, newId=newID, newBaudrateVal=newBaudrateVal, newParityVal=newParity, newResponseTime=newRespTime)
    print("SerialWRITE flag >>", hex(flag))
    
    # サーボのSystemWRITEコマンドの処理が完了するまで待つ
    time.sleep(0.5)
    
    # サーボ側の通信速度を3Mbpsに変更したため
    # PCのSerial部分の通信速度も3Mbpsに変更する
    # PCの通信速度はPMXの通信速度設定値ではなく、直接通信速度を渡します
    pmx.setSerialParameters(baudrate=newBaudrate)
    
    # IDのみを書き換える場合はsetId関数を使用します
    print("SetId関数を使って書き変えたIDを元に戻します")
    nowID = 10  # 書き変えたIDにアクセスします
    newID = ServoID  # もともとのIDに書き戻します
    
    flag = pmx.setId(nowID, newID)  # setIdは関数内部でserialNumを取得しているので読み出す必要はありません
    print("setId flag >>", hex(flag))
    
    # サーボのSystemWRITEコマンドの処理が完了するまで待つ
    time.sleep(0.5)
    
    # Baudrateのみを書き換える場合はsetBaudrate関数を使用します
    print("setBaudrate関数を使って元の通信速度にもどします")
    newBaudrate = pmxBaudrate   # もともと設定してあった通信速度に書き変えます
                                # setBaudrate関数は内部で通信速度値に変換するため直接通信速度を渡します
    flag = pmx.setBaudrate(ServoID, newBaudrate)  # setBaudrateは関数内部でserialNumを取得しているので読み出す必要はありません
    print("setBaudrate flag>>", hex(flag))
    

    
    # サーボのSystemWRITEコマンドの処理が完了するまで待つ
    time.sleep(0.5)

    # サーボ側の通信速度を初期状態に戻したため
    # PCのSerial部分の通信速度も初期状態に変更します
    pmx.setSerialParameters(baudrate=newBaudrate)

    
    pmx.close()


""" main """
if __name__ == "__main__":
    main()
